==> gtktalog-0.15.1.tar.gz: gtktalog-0.15.1/src/gtktalog/addisk.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __ADDISK_H__
#define __ADDISK_H__

#include "config_common.h"

#define ADDED_DISK_UNDEF	0
#define ADDED_DISK_OK		1
#define ADDED_DISK_NOK		2
#define ADDED_DISK_DELETE	3
#define ADDED_DISK_STOP		4

guint du_s (gchar * path);
gboolean eject_disk(CONFIG *my_config);
gboolean mount_disk(CONFIG *my_config);
gboolean umount_disk(CONFIG *my_config);

gint get_thread_status ();

void do_not_forget_to_umount (gboolean gb);
void do_not_forget_to_mount (gboolean gb);
void set_local_disk_name (gchar * s);
void set_local_folder_name (gchar * s);
void set_added_disk (gint gb);
void init_vfs_scan_status(void);

gint my_timeout (gpointer data);

void fad_wait_window (void);

gchar *read_information (gchar * file, gchar * mime);
gboolean create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
			 gboolean getInformation, gint testvfs);
void *start_thread_scan (void *arg);
void finish_normal_scan (int sig);
gchar *escapespaces(gchar *txt);

#endif

==> gtktalog_1.0.4.orig.tar.gz: gtktalog-1.0.4/src/gtktalog/addisk.h <==
/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __ADDISK_H__
#define __ADDISK_H__

#include "config_common.h"

#define ADDED_DISK_UNDEF	0
#define ADDED_DISK_OK		1
#define ADDED_DISK_NOK		2
#define ADDED_DISK_DELETE	3
#define ADDED_DISK_STOP		4

void display_message_if_necessary (void);

guint du_s (gchar * path);
gboolean eject_disk (CONFIG * my_config);
gboolean mount_disk (CONFIG * my_config);
gboolean umount_disk (CONFIG * my_config);

gint get_thread_status ();

void do_not_forget_to_umount (gboolean gb);
void do_not_forget_to_mount (gboolean gb);
void set_local_disk_name (gchar * s);
void set_local_folder_name (gchar * s);
void reset_added_disk (void);
void set_added_disk (gint gb);
gboolean test_abort_scan (void);
void init_vfs_scan_status (void);

gint my_timeout (gpointer data);

void fad_wait_window (void);

gchar *read_information (gchar * file, gchar * mime);
gboolean create_folder_tree (FOLDER * racine, GNode * parent,
			     const gchar * path, gboolean getInformation,
			     gint testvfs);
int mount_disk_if_necessary (void);
void *start_thread_scan (void *arg);
void finish_normal_scan (int sig);
gchar *escapespaces (gchar * txt);
#  ifdef OS_PPC_DARWIN
gchar *mosx_get_cd_mount_point (int);
#  endif

#endif
